from distutils.core import setup
setup(
  name = 'neutron_detector_eff_functions',
  packages = ['neutron_detector_eff_functions'],
  version = '0.1.5',
  description = 'A library to calculate Neutron detector theoretical efficiency',
  author = 'acarmona',
  author_email = 'acarmona@opendeusto.es',
  url = 'https://github.com/alvcarmona/neutronDetectorEffFunctions', # URL to the github repo
  download_url = 'https://github.com/alvcarmona/neutronDetectorEffFunctions/archive/0.1.5.tar.gz',
  keywords = ['science'],
  classifiers = [],
  include_package_data=True
)

